@@ -9,6 +9,14 @@ class SelectionScreen(field.Field):
         self._path = "wnd[0]/usr/ctxtS_RUNID-LOW"
         return self
 
+    def angelegt_am_von(self):
+        self._path = "wnd[0]/usr/ctxtS_IMPDAT-LOW"
+        return self
+
+    def angelegt_am_bis(self):
+        self._path = "wnd[0]/usr/ctxtS_IMPDAT-HIGH"
+        return self
+
     def gruppenschluessel_ai(self):
         self._path = "wnd[0]/usr/ctxtS_AIGRP-LOW"
         return self
